@@ -11,10 +11,10 @@
 #'
 #' @author Joseph Lewis
 
-transition_slope <- function(x, neighbours) {
+transition_slope <- function(x, neighbours = neighbours) {
     
-    tr <- new("TransitionLayer", nrows = as.integer(nrow(x)), ncols = as.integer(ncol(x)), extent = extent(x), crs = projection(x, asText = FALSE), transitionMatrix = Matrix(0, 
-        ncell(x), ncell(x)), transitionCells = 1:ncell(x))
+    tr <- new("TransitionLayer", nrows = as.integer(nrow(x)), ncols = as.integer(ncol(x)), extent = extent(x), crs = projection(x, asText = FALSE), 
+        transitionMatrix = Matrix(0, ncell(x), ncell(x)), transitionCells = 1:ncell(x))
     transitionMatr <- transitionMatrix(tr)
     Cells <- which(!is.na(getValues(x)))
     
